@@ -7,21 +7,16 @@
 #if defined(__cplusplus) || defined(c_plusplus)
 extern "C" {
 #endif
-
-#define ErrorQueueLength  16
-#define NodesInAList  2048
+
+/*
+  Define declarations.
+*/
+#define MaxTreeDepth  8
+#define NodesInAList  1536
 
 /*
   Typedef declarations.
 */
-typedef struct _ErrorPacket
-{
-  int
-    red,
-    green,
-    blue;
-} ErrorPacket;
-
 typedef struct _QuantizeInfo
 {
   unsigned int
@@ -31,37 +26,32 @@ typedef struct _QuantizeInfo
 
   ColorspaceType
     colorspace;
-} QuantizeInfo;
-
-/*
-  Constant declarations.
-*/
-extern const int
-  MaxTreeDepth;
 
-extern const long
-  MaxColormapSize;
+  unsigned int
+    measure_error,
+    signature;
+} QuantizeInfo;
 
 /*
   Quantization utilities methods.
 */
-extern Export QuantizeInfo
+extern MagickExport QuantizeInfo
   *CloneQuantizeInfo(const QuantizeInfo *);
 
-extern Export unsigned int
-  MapImage(Image *,const Image *,const unsigned int),
-  MapImages(Image *,const Image *,const unsigned int),
+extern MagickExport unsigned int
+  MapImage(Image *,Image *,const unsigned int),
+  MapImages(Image *,Image *,const unsigned int),
   QuantizationError(Image *),
   QuantizeImage(const QuantizeInfo *,Image *),
   QuantizeImages(const QuantizeInfo *,Image *),
-  QueryColorName(const ColorPacket *,char *),
+  QueryColorName(const PixelPacket *,char *),
   SegmentImage(Image *,const ColorspaceType,const unsigned int,const double,
     const double);
 
-extern Export unsigned long
-  GetNumberColors(const Image *,FILE *);
+extern MagickExport unsigned long
+  GetNumberColors(Image *,FILE *);
 
-extern Export void
+extern MagickExport void
   DestroyQuantizeInfo(QuantizeInfo *),
   GetQuantizeInfo(QuantizeInfo *);
 
